@@ -2,7 +2,7 @@
 /*
   This code is part of FusionDirectory (http://www.fusiondirectory.org/)
   Copyright (C) 2003-2010  Cajus Pollmeier
-  Copyright (C) 2011-2013  FusionDirectory
+  Copyright (C) 2011-2016  FusionDirectory
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,8 +31,8 @@ session::global_set('errorsAlreadyPosted', array());
 
 /* Logged in? Simple security check */
 if (!session::global_is_set('ui')) {
-  new log("security", "unknown", "", array(), "Error: getbin.php called without session");
-  header ("Location: index.php");
+  logging::log('security', 'unknown', '', array(), 'Error: getbin.php called without session');
+  header ('Location: index.php');
   exit;
 }
 
