@@ -25,6 +25,9 @@
  *                                            for an example see Menu.prototype.config
  */
 var Menu = Class.create();
+var MenuContainer = Class.create();
+var MenuItem = Class.create();
+
 Menu.prototype = {
 
   initialize: function(idOrElement, name, customConfigFunction) {
@@ -50,7 +53,6 @@ Menu.prototype = {
 
 }
 
-var MenuContainer = Class.create();
 MenuContainer.prototype = {
   initialize: function(idOrElement, parent) {
     this.type = "menuContainer";
@@ -69,13 +71,12 @@ MenuContainer.prototype = {
     this.id = this.element.id;
 
     if (this.type === "menuContainer") {
-      if (this.element.hasClassName("level1")) {
+      if (this.element.hasClassName("level1"))
         this.menuType = "horizontal";
-      } else if (this.element.hasClassName("level2")) {
+      else if (this.element.hasClassName("level2"))
         this.menuType = "dropdown";
-      } else {
+      else
         this.menuType = "flyout";
-      }
 
       if (this.menuType === "flyout" || this.menuType === "dropdown") {
         this.isOpen = false;
@@ -96,7 +97,7 @@ MenuContainer.prototype = {
     if (childNodes === null) {
       return;
     }
-
+    
     for (var i = 0; i < childNodes.length; i++) {
       var node = childNodes[i];
       if (node.nodeType === 1) {
@@ -113,18 +114,17 @@ MenuContainer.prototype = {
     }
   },
 
-  getBorders: function(element) {
+  getBorders: function() {
     var ltrb = ["Left","Top","Right","Bottom"];
     var result = {};
     var value;
     for (var i = 0; i < ltrb.length; ++i) {
-      if (this.element.currentStyle) {
+      if (this.element.currentStyle)
         value = parseInt(this.element.currentStyle["border"+ltrb[i]+"Width"]);
-      } else if (window.getComputedStyle) {
+      else if (window.getComputedStyle)
         value = parseInt(window.getComputedStyle(this.element, "").getPropertyValue("border-"+ltrb[i].toLowerCase()+"-width"));
-      } else {
+      else
         value = parseInt(this.element.style["border"+ltrb[i]]);
-      }
       result[ltrb[i].toLowerCase()] = isNaN(value) ? 0 : value;
     }
     return result;
@@ -177,9 +177,6 @@ MenuContainer.prototype = {
 
 }
 
-
-var MenuItem = Class.create();
-
 Object.extend(Object.extend(MenuItem.prototype, MenuContainer.prototype), {
   initialize: function(idOrElement, parent) {
     var menuItem = this;
@@ -208,6 +205,7 @@ Object.extend(Object.extend(MenuItem.prototype, MenuContainer.prototype), {
         if (menuItem.root.openDelayTimer) {
           window.clearTimeout(menuItem.root.openDelayTimer);
         }
+        
         if (menuItem.root.closeDelayTimer) {
           window.clearTimeout(menuItem.root.closeDelayTimer);
         }
@@ -232,10 +230,8 @@ Object.extend(Object.extend(MenuItem.prototype, MenuContainer.prototype), {
   }
 });
 
-
 var menu;
 
-
 function configMenu() {
   this.closeDelayTime = 300;
 }
@@ -244,5 +240,4 @@ function initMenu() {
   menu = new Menu('root', 'menu', configMenu);
 }
 
-
 Event.observe(window, 'load', initMenu, false);
