@@ -3,7 +3,7 @@
 /*
   This code is part of FusionDirectory (http://www.fusiondirectory.org/)
   Copyright (C) 2003-2010  Cajus Pollmeier
-  Copyright (C) 2011-2013  FusionDirectory
+  Copyright (C) 2011-2016  FusionDirectory
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -49,22 +49,22 @@ if ($_SERVER["REQUEST_METHOD"] == "POST") {
 
 /* Logged in? Simple security check */
 if (!session::global_is_set('connected')) {
-  new log("security", "login", "", array(), "main.php called without session - logging out");
-  header ("Location: logout.php");
+  logging::log('security', 'login', '', array(), 'main.php called without session - logging out');
+  header ('Location: index.php?message=nosession');
   exit;
 }
 
 /* Check for uniqe ip address */
 $ui = session::global_get('ui');
 if ($_SERVER['REMOTE_ADDR'] != $ui->ip) {
-  new log("security", "login", "", array(), "main.php called with session which has a changed IP address.");
-  header ("Location: logout.php");
+  logging::log('security', 'login', '', array(), 'main.php called with session which has a changed IP address.');
+  header ('Location: index.php?signout=1&message=newip');
   exit;
 }
 $config = session::global_get('config');
 
 /* If SSL is forced, just forward to the SSL enabled site */
-if (($config->get_cfg_value("forcessl") == "TRUE") && ($ssl != '')) {
+if (($config->get_cfg_value('forcessl') == 'TRUE') && ($ssl != '')) {
   header ("Location: $ssl");
   exit;
 }
@@ -72,27 +72,26 @@ if (($config->get_cfg_value("forcessl") == "TRUE") && ($ssl != '')) {
 timezone::setDefaultTimezoneFromConfig();
 
 /* Check for invalid sessions */
-if (session::global_get('_LAST_PAGE_REQUEST') == "") {
-  session::global_set('_LAST_PAGE_REQUEST', time());
-} else {
-
+if (session::global_get('_LAST_PAGE_REQUEST') != '') {
   /* check FusionDirectory.conf for defined session lifetime */
-  $max_life = $config->get_cfg_value("sessionLifetime", 60 * 60 * 2);
+  $max_life = $config->get_cfg_value('sessionLifetime', 60 * 60 * 2);
 
-  /* get time difference between last page reload */
-  $request_time = (time() - session::global_get('_LAST_PAGE_REQUEST'));
+  if ($max_life > 0) {
+    /* get time difference between last page reload */
+    $request_time = (time() - session::global_get('_LAST_PAGE_REQUEST'));
 
-  /* If page wasn't reloaded for more than max_life seconds
-   * kill session
-   */
-  if ($request_time > $max_life) {
-    session::destroy();
-    new log("security", "login", "", array(), "main.php called without session - logging out");
-    header ("Location: logout.php");
-    exit;
+    /* If page wasn't reloaded for more than max_life seconds
+     * kill session
+     */
+    if ($request_time > $max_life) {
+      session::destroy();
+      logging::log('security', 'login', '', array(), 'main.php called with expired session - logging out');
+      header ('Location: index.php?signout=1&message=expired');
+      exit;
+    }
   }
-  session::global_set('_LAST_PAGE_REQUEST', time());
 }
+session::global_set('_LAST_PAGE_REQUEST', time());
 
 
 @DEBUG (DEBUG_CONFIG, __LINE__, __FUNCTION__, __FILE__, $config->data, "config");
@@ -117,7 +116,7 @@ if (isset($global_check) && $config->get_cfg_value("forceglobals") == "TRUE") {
             _("Fatal error: Register globals is on. FusionDirectory will refuse to login unless this is fixed by an administrator."),
             FATAL_ERROR_DIALOG);
 
-  new log("security", "login", "", array(), "Register globals is on. For security reasons, this should be turned off.");
+  logging::log('security', 'login', '', array(), 'Register globals is on. For security reasons, this should be turned off.');
   session::destroy ();
   exit;
 }
@@ -135,12 +134,12 @@ $plist->gen_menu();
 $smarty->assign("hideMenus", FALSE);
 if ($config->get_cfg_value("handleExpiredAccounts") == "TRUE") {
   $expired = $ui->expired_status();
-  if ($expired == POSIX_WARN_ABOUT_EXPIRATION && !session::is_set('POSIX_WARN_ABOUT_EXPIRATION__DONE')) {
-    @DEBUG (DEBUG_TRACE, __LINE__, __FUNCTION__, __FILE__, $expired, "This user account (".$ui->username.") is about to expire");
+  if (($expired == POSIX_WARN_ABOUT_EXPIRATION) && !session::is_set('POSIX_WARN_ABOUT_EXPIRATION__DONE')) {
+    @DEBUG (DEBUG_TRACE, __LINE__, __FUNCTION__, __FILE__, $expired, 'This user account ('.$ui->uid.') is about to expire');
 
     // The users password is about to xpire soon, display a warning message.
-    new log("security", "fusiondirectory", "", array(), "password for user '".$ui->username."' is about to expire");
-    msg_dialog::display(_("Password change"), _("Your password is about to expire, please change your password!"), INFO_DIALOG);
+    logging::log('security', 'fusiondirectory', '', array(), 'password for user "'.$ui->uid.'" is about to expire');
+    msg_dialog::display(_('Password change'), _('Your password is about to expire, please change your password!'), INFO_DIALOG);
     session::set('POSIX_WARN_ABOUT_EXPIRATION__DONE', TRUE);
   } elseif ($expired == POSIX_FORCE_PASSWORD_CHANGE) {
     @DEBUG (DEBUG_TRACE, __LINE__, __FUNCTION__, __FILE__, $expired, "This user account expired");
@@ -151,11 +150,12 @@ if ($config->get_cfg_value("handleExpiredAccounts") == "TRUE") {
     $smarty->assign("hideMenus", TRUE);
     $plug = (isset($_GET['plug'])) ? $_GET['plug'] : NULL;
 
-    // Search for the 'password' class and set its id as active plug.
+    // Search for the 'user' class and set its id as active plug.
     foreach ($plist->dirlist as $key => $value) {
-      if (preg_match("/\bpassword\b/i", $value)) {
-        if ($plug != $key) {
+      if ($value == 'user') {
+        if (!isset($_GET['plug']) || ($_GET['plug'] != $key)) {
           $_GET['plug'] = $key;
+          msg_dialog::display(_('Warning'), _('Your password has expired, please set a new one.'), WARNING_DIALOG);
         }
         break;
       }
@@ -167,14 +167,14 @@ if (isset($_GET['plug']) && $plist->plugin_access_allowed($_GET['plug'])) {
   $plug       = validate($_GET['plug']);
   $plugin_dir = $plist->get_path($plug);
   session::global_set('plugin_dir', $plugin_dir);
-  if ($plugin_dir == "") {
-    new log("security", "fusiondirectory", "", array(), "main.php called with invalid plug parameter \"$plug\"");
-    header ("Location: logout.php");
+  if ($plugin_dir == '') {
+    logging::log('security', 'fusiondirectory', '', array(), "main.php called with invalid plug parameter \"$plug\"");
+    header ('Location: index.php?signout=1&message=invalidparameter&plug='.$plug);
     exit;
   }
 } else {
   /* set to welcome page as default plugin */
-  session::global_set('plugin_dir', "welcome");
+  session::global_set('plugin_dir', 'welcome');
   $plugin_dir = "$BASE_DIR/plugins/generic/welcome";
 }
 
@@ -229,15 +229,6 @@ if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['password_back'])) {
   exit;
 }
 
-/* Check for multiple windows logout */
-if ($_SERVER["REQUEST_METHOD"] == "POST") {
-  if (isset($_POST['reset_session'])) {
-    header ("Location: logout.php");
-    exit;
-  }
-}
-
-
 /* Load department list when plugin has changed. That is some kind of
    compromise between speed and beeing up to date */
 if (isset($_GET['reset'])) {
@@ -257,9 +248,9 @@ if (isset($plug)) {
 }
 
 if ($ui->ignore_acl_for_current_user()) {
-  $smarty->assign ("username", "<div style='color:#FF0000;'>"._("User ACL checks disabled")."</div>&nbsp;".$ui->username);
+  $smarty->assign ('username', '<div style="color:#FF0000;">'._('User ACL checks disabled').'</div>&nbsp;'.$ui->uid);
 } else {
-  $smarty->assign ("username", $ui->username);
+  $smarty->assign ('username', $ui->uid);
 }
 $smarty->assign ("menu", $plist->menu);
 $smarty->assign ("plug", "$plug");
@@ -318,7 +309,7 @@ if (isset($_POST) && count($_POST)) {
   }
 }
 
-/* Assign erros to smarty */
+/* Assign errors to smarty */
 if (session::is_set('errors')) {
   $smarty->assign("errors", session::get('errors'));
 }
